numpy.record
============

.. currentmodule:: numpy

.. autoclass:: record

   

   .. HACK
      .. autosummary::
         :toctree:
      
         record.__init__
         record.all
         record.any
         record.argmax
         record.argmin
         record.argsort
         record.astype
         record.byteswap
         record.choose
         record.clip
         record.compress
         record.conj
         record.conjugate
         record.copy
         record.cumprod
         record.cumsum
         record.diagonal
         record.dump
         record.dumps
         record.fill
         record.flatten
         record.getfield
         record.item
         record.itemset
         record.max
         record.mean
         record.min
         record.newbyteorder
         record.nonzero
         record.pprint
         record.prod
         record.ptp
         record.put
         record.ravel
         record.repeat
         record.reshape
         record.resize
         record.round
         record.searchsorted
         record.setfield
         record.setflags
         record.sort
         record.squeeze
         record.std
         record.sum
         record.swapaxes
         record.take
         record.tofile
         record.tolist
         record.tostring
         record.trace
         record.transpose
         record.var
         record.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         record.T
         record.base
         record.data
         record.dtype
         record.flags
         record.flat
         record.imag
         record.itemsize
         record.nbytes
         record.ndim
         record.real
         record.shape
         record.size
         record.strides

